package MBF::Test;

#<<<
use     strict;
use     5.005;
use     vars        qw( $VERSION );
#>>>

use Path::Class;

# The equivalent of "use warnings" pre-5.006.
local $^W = 1;

$VERSION = '0.001_006';

1;