package MBF::Test3;

#<<<
use     strict;
use     5.008001;
use     vars        qw( $VERSION );
#>>>

# The equivalent of "use warnings" pre-5.006.
local $^W = 1;

$VERSION = '0.002';

=pod

=head1 NAME

MBF::Test3 - Second test module for Module::Build::Functions

=head1 AUTHORS

Curtis Jewell E<lt>csjewell@cpan.orgE<gt>

=head1 END_TEST

=cut

1;